/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "../libs.h"
#include "../util/array.h"
#include "poker.h"

/**
 * Adds a new pot to the poker game instance.
 * 
 * @param poker Poker game instance to add a pot to.
 * @return The index of the pot within the array of pots.
 */
uint8_t pokerPotAdd(poker_t *poker);

/**
 * Check whether or not the given player is part of the given pot.
 * 
 * @param pot Pot to check.
 * @param playerIndex Player index to see if within the pot or not.
 * @return True if in the pot, otherwise false.
 */
bool pokerPotHasPlayer(pokerpot_t *pot, uint8_t playerIndex);

/**
 * Add a player to a pot. This will not let you add the same player to the pot
 * twice.
 * 
 * @param pot Pot to add to.
 * @param playerIndex Players' index to add to the pot.
 */
void pokerPotAddPlayer(pokerpot_t *pot, uint8_t playerIndex);